# when updating, please rebuild ldetect as it is compiled against this static library

%bcond_with	bootstrap
%bcond_with	diet
%bcond_with	uclibc

%define	major	3
%define	libname	%mklibname pci %{major}
%define	devname	%mklibname pci -d

Summary:	PCI bus related utilities
Name:		pciutils
Version:	3.2.0
Release:	6
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		http://atrey.karlin.mff.cuni.cz/~mj/pciutils.shtml
Source0:	ftp://atrey.karlin.mff.cuni.cz/pub/linux/pci/%{name}-%{version}.tar.gz
Patch0:		pciutils-3.0.3-use-stdint.patch
Patch10:	pciutils-3.1.2-pcimodules.patch
Patch11:	pciutils-3.0.3-cardbus-only-when-root.patch
# allow build with dietlibc, using sycall() and sys/io.h
Patch20:	pciutils-2.2.6-noglibc.patch
# allow build with dietlibc, not using unsupported features:
Patch21:	pciutils-3.0.3-fix-compiliing-w-diet.patch
Patch22:	pciutils-3.1.10-LDFLAGS.patch

# upstream fixes / addons
Patch51:	0001-lspci-Display-CardBus-bridge-capabilities.patch
Patch52:	0002-lspci-Fully-decode-ASPM-support-from-Link-Capabiliti.patch
Patch53:	0003-lspci-Add-L1-PM-Substate-capability-reporting.patch
Patch54:	0004-Added-a-test-case-for-the-L1-PM-capability.patch
Patch55:	0005-lspci-Make-output-of-L1-PM-cap-consistent-with-other.patch

# Fedora patches
# (TV) all but 106 & 109 (which we disabled) were droped by fedora!
# don't segfault on systems without PCI bus (rhbz #84146)
Patch102:	pciutils-2.1.10-scan.patch
# use pread/pwrite, ifdef check is obsolete nowadays
Patch103:	pciutils-havepread.patch
# change pci.ids directory to hwdata
Patch106:	pciutils-2.2.1-idpath.patch
# multilib support
Patch108:	pciutils-3.0.2-multilib.patch
# add support for directory with another pci.ids
Patch109:	pciutils-dir-d.patch
# platform support 3x
Patch110:	pciutils-2.2.10-sparc-support.patch
Patch111:	pciutils-3.0.1-superh-support.patch
Patch112:	pciutils-3.1.8-arm.patch

# needed to support modaliases so lspci -k gives correct output
BuildRequires:	kmod-devel
%if %{with diet}
BuildRequires:	dietlibc-devel
%endif
%if %{with uclibc}
BuildRequires:	uClibc-devel >= 0.9.33.2
%endif
%if !%{with bootstrap}
Requires:	pciids
%endif
# matching lib is always needed (mga #10661)
Requires:	%{libname} = %{EVRD}
Requires:	hwdata
Provides:	pciids = %{EVRD}

%description
This package contains various utilities for inspecting and setting
devices connected to the PCI bus.

%files
%doc README ChangeLog pciutils.lsm
%{_mandir}/man8/*
%{_bindir}/lspci
%{_bindir}/pcimodules
%{_bindir}/setpci
%{_sbindir}/update-pciids

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	The PCI library
Group:		System/Libraries

%description -n	%{libname}
This package contains a dynamic library for inspecting and setting
devices connected to the PCI bus.

%files -n %{libname}
%{_libdir}/libpci.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Linux PCI development library
Group:		Development/C
Requires:	%{libname}  = %{EVRD}
Provides:	pciutils-devel = %{EVRD}

%description -n	%{devname}
This package contains a library for inspecting and setting
devices connected to the PCI bus.

%files -n %{devname}
%doc TODO
%{_libdir}/*.a
%{_libdir}/*.so
%if %{with diet}
%{_prefix}/lib/dietlibc/lib-%{_arch}/libpci.a
%endif
%if %{with uclibc}
%{uclibc_root}%{_libdir}/libpci.a
%endif
%dir %{_includedir}/pci
%{_includedir}/pci/*.h
%{_libdir}/pkgconfig/libpci.pc

#----------------------------------------------------------------------------

%prep
%setup -q
%patch0 -p0
%patch10 -p1
%patch11 -p0
%patch20 -p1
%patch21 -p1
%patch22 -p1

%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1

%patch102 -p1 -b .scan~
%patch103 -p1 -b .pread~
%patch106 -p1 -b .idpath~
%patch108 -p1 -b .multilib~
# fixme:?
%patch109 -p1 -b .dird~
%patch110 -p1 -b .sparc~
%patch111 -p1 -b .superh~
%patch112 -p1 -b .arm~

%build
sed -i -e 's|^SRC=.*|SRC="http://pciids.sourceforge.net/pci.ids"|' update-pciids.sh

%if %{with diet}
%make PREFIX=%{_prefix} ZLIB=no OPT="-Os -D__USE_DIETLIBC" LDFLAGS="%{ldflags}" CC="diet gcc" DNS=no IDSDIR="/usr/share/hwdata" PCI_IDS="pci.ids" lib/libpci.a
cp lib/libpci.a libpci.a.diet
make clean
%endif
%if %{with uclibc}
%make PREFIX=%{_prefix} ZLIB=no OPT="%{uclibc_cflags}" LDFLAGS="%{ldflags}" CC="%{uclibc_cc}" DNS=no IDSDIR="/usr/share/hwdata" PCI_IDS="pci.ids" lib/libpci.a
cp lib/libpci.a libpci.a.uclibc
make clean
%endif

%make PREFIX=%{_prefix} OPT="%{optflags} -fPIC" ZLIB=no SHARED=no DNS=no LDFLAGS="%{ldflags}" IDSDIR="/usr/share/hwdata" PCI_IDS="pci.ids" lib/libpci.a 
cp lib/libpci.a lib/libpci.a.libc
make clean

# do not build with zlib support since it's useless (only needed if we compress
# pci.ids which we cannot do since hal mmaps it for memory saving reason)
%make PREFIX=%{_prefix} OPT="%{optflags} -fPIC" ZLIB=no SHARED=yes LDFLAGS="%{ldflags}" IDSDIR="/usr/share/hwdata" PCI_IDS="pci.ids"

%install
install -d %{buildroot}{%{_bindir},%{_sbindir},%{_mandir}/man8,%{_libdir}/pkgconfig,%{_includedir}/pci}

install pcimodules lspci setpci %{buildroot}%{_bindir}
install update-pciids %{buildroot}%{_sbindir}
install -m 644 pcimodules.man lspci.8 setpci.8 %{buildroot}%{_mandir}/man8
install -m 644 lib/libpci.a.libc %{buildroot}%{_libdir}/libpci.a
install lib/libpci.so.%{major}.* %{buildroot}%{_libdir}
ln -s libpci.so.3 %{buildroot}%{_libdir}/libpci.so
%if %{with diet}
install -m644 libpci.a.diet -D %{buildroot}%{_prefix}/lib/dietlibc/lib-%{_arch}/libpci.a
%endif
%if %{with uclibc}
install -m644 libpci.a.uclibc -D %{buildroot}%{uclibc_root}%{_libdir}/libpci.a
%endif

install -m 644 lib/{pci.h,header.h,config.h,types.h} %{buildroot}%{_includedir}/pci
install -m 644 lib/libpci.pc %{buildroot}%{_libdir}/pkgconfig/


%changelog
* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 3.2.0-6
+ Revision: 43d7a7c
- MassBuild#440: Increase release tag


